#ifndef lint
static char const 
yyrcsid[] = "$FreeBSD: src/usr.bin/yacc/skeleton.c,v 1.28 2000/01/17 02:04:06 bde Exp $";
#endif
#include <stdlib.h>
#define YYBYACC 1
#define YYMAJOR 1
#define YYMINOR 9
#define YYLEX yylex()
#define YYEMPTY -1
#define yyclearin (yychar=(YYEMPTY))
#define yyerrok (yyerrflag=0)
#define YYRECOVERING() (yyerrflag!=0)
static int yygrowstack();
#define yyparse conf_yyparse
#define yylex conf_yylex
#define yyerror conf_yyerror
#define yychar conf_yychar
#define yyval conf_yyval
#define yylval conf_yylval
#define yydebug conf_yydebug
#define yynerrs conf_yynerrs
#define yyerrflag conf_yyerrflag
#define yyss conf_yyss
#define yyssp conf_yyssp
#define yyvs conf_yyvs
#define yyvsp conf_yyvsp
#define yylhs conf_yylhs
#define yylen conf_yylen
#define yydefred conf_yydefred
#define yydgoto conf_yydgoto
#define yysindex conf_yysindex
#define yyrindex conf_yyrindex
#define yygindex conf_yygindex
#define yytable conf_yytable
#define yycheck conf_yycheck
#define yyname conf_yyname
#define yyrule conf_yyrule
#define yysslim conf_yysslim
#define yystacksize conf_yystacksize
#define YYPREFIX "conf_yy"
#line 2 "confgrammer.y"
/***************************************************************************
                          confgrammer.y  -  description
                             -------------------
    copyright            : (C) 2002 by Willy De la Court
    email                : willy.delacourt@pandora.be
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License version 2 as     *
 *   published by the Free Software Foundation                             *
 *                                                                         *
 ***************************************************************************/


#include <stdio.h>
#include <string.h>
#include <qstringlist.h>
#include "confparser.h"

#define YYSTYPE char *
#define YYDEBUG 1
#define YYMAXDEPTH 0
#define YYPARSE_PARAM conf_parser

extern int yylex(void);
extern int conf_lineno;

ConfParser *conf_p = 0;
QString ip_list;
int global;
dataItem *conf_data = 0L;
subnetItem *currentSubnet = 0L;
hostItem *currentHost = 0L;

void yyerror(const char *str)
{
	if( conf_p )
		conf_p->addSyntaxError( conf_lineno );
	fprintf(stderr,"error: %s in line %d\n", str, conf_lineno);
}

void conf_init( void *conf_parser )
{
	conf_p = static_cast<ConfParser *>(conf_parser);
}

void add_range(const char *r1, const char *r2, bool bootp)
{
	conf_data = new rangeItem(r1, r2, bootp);
	if(currentSubnet)
		currentSubnet->addRange((rangeItem *) conf_data);
	/*if(bootp)*/
	/*	printf("*range dynamic-bootp %s %s*\n", r1, r2);*/
	/*else*/
	/*	printf("*range %s %s*\n", r1, r2);*/
}

void add_option_to_tree(void *conf_parser)
{
	if(currentHost)
		currentHost->addOption(conf_data);
	else {
		if (currentSubnet)
			currentSubnet->addOption(conf_data);
		else {
			if(global) {
				/*printf("global ");*/
				ConfParser *p = static_cast<ConfParser *>(conf_parser);
				p->addGlobal(conf_data);
			}
		}
	}
}

void add_option(const char *txt, const char *val, void *conf_parser, bool quotes = false)
{
	conf_data = new optionItem(txt, val, quotes);
	add_option_to_tree(conf_parser);
	/*printf("*option %s %s*\n", txt, val);*/
}

void add_option2(const char *txt, const char *val, void *conf_parser)
{
	conf_data = new dataItem(txt, val);
	add_option_to_tree(conf_parser);
	/*printf("*%s %s*\n", txt, val);*/
}

void add_option_time(const char *txt, const char *val, void *conf_parser)
{
	conf_data = new dataItem(txt, val, "time");
	add_option_to_tree(conf_parser);
	/*printf("*%s %s*\n", txt, val);*/
}

#define INIT()					conf_init(conf_parser);
#define ADD_RANGE(r1, r2)		add_range(r1, r2, false);
#define ADD_RANGE2(r1, r2)		add_range(r1, r2, true);
#define ADD_OPTION(var, txt, val) 	add_option(txt, val, conf_parser);
#define ADD_OPTIONQ(var, txt, val) 	add_option(txt, val, conf_parser, true);
#define ADD_OPTION2(var, txt, val) 	add_option2(txt, val, conf_parser);
#define ADD_OPTION_TIME(var, txt, val) 	add_option_time(txt, val, conf_parser);
#define SET_LIST_SA(var, txt) 		add_option(txt, ip_list, conf_parser);
#define NEW_SCOPE(subnet, netmask) 	currentSubnet = new subnetItem(subnet, netmask); \
					conf_data = currentSubnet; \
					/*printf("subnet(%s, %s)\n", subnet, netmask);*/
#define SAVE_SCOPE() 			ConfParser *p = static_cast<ConfParser *>(conf_parser); \
					p->addSubnet(currentSubnet); \
					/*printf("saving subnet\n");*/
#define NEW_HOST(name)			currentHost = new hostItem(name); \
					conf_data = currentHost; \
					/*printf("*host %s*\n", name);*/
#define SAVE_HOST()			if(currentSubnet) { \
						currentSubnet->addHost(currentHost); \
						currentHost = 0L; \
					} \
					/*printf("saving host\n");*/
#define SET_GLOBAL()			global = 1;
#define CLEAR_GLOBAL()			global = 0;
#define SET_COMMENT(val)		if(conf_data) \
						conf_data->setComment(val); \
					/*printf("comment %s\n", val);*/

#line 169 "confgrammer.tab.c"
#define YYERRCODE 256
#define SUBNET 257
#define NETMASK 258
#define BYTE 259
#define WORD 260
#define OPTION 261
#define SUBNETMASK 262
#define ROUTERS 263
#define NISDOMAIN 264
#define IPFORWARDING 265
#define DOMAINNAME 266
#define DOMAINNAMESERVERS 267
#define BROADCASTADDRESS 268
#define NETBIOSNAMESERVERS 269
#define NETBIOSDDSERVER 270
#define NETBIOSNODETYPE 271
#define TIMEOFFSET 272
#define QUOTE 273
#define IP 274
#define RANGE 275
#define DYNAMICBOOTP 276
#define DEFAULTLEASETIME 277
#define MAXLEASETIME 278
#define HOST 279
#define NEXTSERVER 280
#define FIXEDADDRESS 281
#define HARDWARE 282
#define ETHERNET 283
#define NUMBER 284
#define MAC 285
#define DOMAIN 286
#define COMMENT 287
const short conf_yylhs[] = {                                        -1,
    0,    0,    3,    1,    1,    1,    1,    6,    5,    7,
    7,    8,    8,    8,    8,    8,    9,    9,    2,    2,
    2,    2,    2,    2,    2,    2,    2,    2,    2,    2,
   12,   10,   13,   13,   13,   13,   13,   14,   14,   14,
   11,   11,   11,   11,    4,    4,   15,
};
const short conf_yylen[] = {                                         2,
    0,    2,    0,    3,    1,    2,    2,    0,   11,    0,
    2,    2,    2,    1,    2,    2,    5,    4,    4,    4,
    4,    4,    4,    4,    4,    6,    6,    4,    3,    3,
    0,    9,    0,    3,    3,    2,    2,    3,    3,    4,
    1,    3,    3,    5,    0,    2,    1,
};
const short conf_yydefred[] = {                                      1,
    0,    0,    0,    2,    0,    5,    7,    6,    0,    0,
    0,    0,   45,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    8,    0,    0,
   41,    0,    0,    0,    0,    0,    0,    0,    0,    0,
   29,   30,   47,   46,   45,   19,    0,   20,    0,    0,
    0,   25,   22,   21,   23,   24,   28,    0,   42,    0,
   43,    0,    0,   45,    0,   26,   27,    0,   44,    0,
    0,   45,    0,    0,   45,   11,   45,   14,   16,   15,
    0,    0,    0,   31,    0,    0,    0,    0,   45,   18,
    0,    0,   17,   45,    0,    0,    0,   37,   36,   45,
    0,    0,    0,   45,   45,    0,    0,    0,    0,    0,
    0,   39,   38,    0,   40,
};
const short conf_yydgoto[] = {                                       1,
    4,   13,    5,   27,    6,   45,   70,   76,   77,   78,
   32,   89,   97,  105,   44,
};
const short conf_yysindex[] = {                                      0,
 -238,  -53, -263,    0, -251,    0,    0,    0, -233, -185,
 -264, -254,    0, -242, -227, -224, -232, -220, -224, -219,
 -224, -224, -230, -228,   -2,    2, -225,    0,    4, -218,
    0,  -31, -217, -206,  -23,    7,  -22,  -20,    8,   29,
    0,    0,    0,    0,    0,    0, -214,    0, -222, -184,
 -182,    0,    0,    0,    0,    0,    0, -123,    0, -194,
    0,   34,   35,    0, -178,    0,    0, -225,    0,  -87,
  -52,    0, -262, -164,    0,    0,    0,    0,    0,    0,
 -225, -177, -176,    0, -225, -225,   40, -174,    0,    0,
   42, -121,    0,    0, -247,  -51, -120,    0,    0,    0,
 -183, -172, -179,    0,    0, -225,   46,   47, -175, -225,
 -225,    0,    0,   48,    0,
};
const short conf_yyrindex[] = {                                      0,
 -244,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    1,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  -67,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    3,    0,    0,    0,  -61,  -55,    0,    0,    0,    0,
    0,    0,    0,    0, -110,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  -35,    0,    0,    0, -102,
  -96,    0,    0,    0,    0,
};
const short conf_yygindex[] = {                                      0,
    0,  -66,    0,  -29,    0,    0,    0,    0,    0,    0,
   23,    0,    0,    0,    0,
};
#define YYTABLESIZE 281
const short conf_yytable[] = {                                      64,
    4,   94,    9,   75,  100,    8,   80,   99,   96,   10,
    9,   82,   49,   83,   33,   58,    3,    2,    3,   25,
   49,   49,   35,   49,   14,   11,   12,   48,   34,   26,
  104,   28,    3,    3,   68,   52,   54,   72,   55,   43,
   33,   35,   81,   37,   38,   85,   29,   86,   30,   31,
   60,   61,   34,   39,   36,   40,   41,   10,   59,   92,
   42,   43,   46,   12,   95,   53,   56,   47,   50,   13,
  106,    7,   79,   98,  110,  111,   15,   16,   17,   51,
   18,   19,   20,   21,   22,   23,   24,   57,   62,   32,
   63,   65,   66,   67,   69,   84,   87,   88,   90,   91,
   93,  108,  107,  109,  112,  113,  115,    0,    0,  114,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
   10,    0,    0,    0,    0,    0,    0,    0,    0,    0,
   33,    0,    0,    0,    0,    0,   11,   12,   35,  101,
  102,  103,    0,   43,   34,   43,   33,   33,   71,   33,
   33,   33,    0,   10,   35,   35,    0,   35,   35,   35,
   34,   34,    0,   34,   34,   34,    0,   73,   10,   11,
   12,   74,    0,   10,   12,    0,    0,    0,    0,   12,
   13,    0,    0,    0,    0,   13,    0,   10,    0,   10,
   10,   10,    0,   12,    0,   12,   12,   12,    0,   13,
   32,   13,   13,   13,    0,   32,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,   32,
    0,   32,   32,   32,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    4,    4,    9,    9,
    0,    4,    0,    9,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    4,    4,    9,
    9,
};
const short conf_yycheck[] = {                                     123,
    0,  123,    0,   70,  125,   59,   59,   59,  256,  261,
  274,  274,   44,  276,  125,   45,  261,  256,  257,  284,
   44,   44,  125,   44,  258,  277,  278,   59,  125,  284,
   97,  274,  277,  278,   64,   59,   59,  125,   59,  287,
  273,   19,   72,   21,   22,   75,  274,   77,  273,  274,
  273,  274,  273,  284,  274,  284,   59,  125,  273,   89,
   59,  287,   59,  125,   94,   59,   59,  286,  286,  125,
  100,  125,  125,  125,  104,  105,  262,  263,  264,  286,
  266,  267,  268,  269,  270,  271,  272,   59,  273,  125,
  273,  286,   59,   59,  273,  260,  274,  274,   59,  274,
   59,  274,  286,  283,   59,   59,   59,   -1,   -1,  285,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  261,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  261,   -1,   -1,   -1,   -1,   -1,  277,  278,  261,  280,
  281,  282,   -1,  287,  261,  287,  277,  278,  256,  280,
  281,  282,   -1,  261,  277,  278,   -1,  280,  281,  282,
  277,  278,   -1,  280,  281,  282,   -1,  275,  256,  277,
  278,  279,   -1,  261,  256,   -1,   -1,   -1,   -1,  261,
  256,   -1,   -1,   -1,   -1,  261,   -1,  275,   -1,  277,
  278,  279,   -1,  275,   -1,  277,  278,  279,   -1,  275,
  256,  277,  278,  279,   -1,  261,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  275,
   -1,  277,  278,  279,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  256,  257,  256,  257,
   -1,  261,   -1,  261,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  277,  278,  277,
  278,
};
#define YYFINAL 1
#ifndef YYDEBUG
#define YYDEBUG 0
#endif
#define YYMAXTOKEN 287
#if YYDEBUG
const char * const conf_yyname[] = {
"end-of-file",0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,"','","'-'","'.'",0,0,0,0,0,0,0,0,0,0,0,0,"';'",0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,"'{'",0,"'}'",0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,"SUBNET",
"NETMASK","BYTE","WORD","OPTION","SUBNETMASK","ROUTERS","NISDOMAIN",
"IPFORWARDING","DOMAINNAME","DOMAINNAMESERVERS","BROADCASTADDRESS",
"NETBIOSNAMESERVERS","NETBIOSDDSERVER","NETBIOSNODETYPE","TIMEOFFSET","QUOTE",
"IP","RANGE","DYNAMICBOOTP","DEFAULTLEASETIME","MAXLEASETIME","HOST",
"NEXTSERVER","FIXEDADDRESS","HARDWARE","ETHERNET","NUMBER","MAC","DOMAIN",
"COMMENT",
};
const char * const conf_yyrule[] = {
"$accept : file",
"file :",
"file : file all",
"$$1 :",
"all : $$1 options comments",
"all : subnet",
"all : error ';'",
"all : error '}'",
"$$2 :",
"subnet : SUBNET IP NETMASK IP $$2 comments '{' comments subnet_parameters '}' comments",
"subnet_parameters :",
"subnet_parameters : subnet_parameters subnet_parameter",
"subnet_parameter : options comments",
"subnet_parameter : range comments",
"subnet_parameter : host",
"subnet_parameter : error ';'",
"subnet_parameter : error '}'",
"range : RANGE DYNAMICBOOTP IP IP ';'",
"range : RANGE IP IP ';'",
"options : OPTION SUBNETMASK IP ';'",
"options : OPTION ROUTERS ip_list ';'",
"options : OPTION NETBIOSNAMESERVERS ip_list ';'",
"options : OPTION BROADCASTADDRESS IP ';'",
"options : OPTION NETBIOSDDSERVER ip_list ';'",
"options : OPTION NETBIOSNODETYPE NUMBER ';'",
"options : OPTION DOMAINNAMESERVERS ip_list ';'",
"options : OPTION NISDOMAIN QUOTE DOMAIN QUOTE ';'",
"options : OPTION DOMAINNAME QUOTE DOMAIN QUOTE ';'",
"options : OPTION TIMEOFFSET NUMBER ';'",
"options : DEFAULTLEASETIME NUMBER ';'",
"options : MAXLEASETIME NUMBER ';'",
"$$3 :",
"host : HOST WORD $$3 comments '{' comments host_options '}' comments",
"host_options :",
"host_options : host_options host_option comments",
"host_options : host_options options comments",
"host_options : error ';'",
"host_options : error '}'",
"host_option : FIXEDADDRESS IP ';'",
"host_option : NEXTSERVER DOMAIN ';'",
"host_option : HARDWARE ETHERNET MAC ';'",
"ip_list : IP",
"ip_list : QUOTE DOMAIN QUOTE",
"ip_list : ip_list ',' IP",
"ip_list : ip_list ',' QUOTE DOMAIN QUOTE",
"comments :",
"comments : comments comment",
"comment : COMMENT",
};
#endif
#ifndef YYSTYPE
typedef int YYSTYPE;
#endif
#if YYDEBUG
#include <stdio.h>
#endif
#ifdef YYSTACKSIZE
#undef YYMAXDEPTH
#define YYMAXDEPTH YYSTACKSIZE
#else
#ifdef YYMAXDEPTH
#define YYSTACKSIZE YYMAXDEPTH
#else
#define YYSTACKSIZE 10000
#define YYMAXDEPTH 10000
#endif
#endif
#define YYINITSTACKSIZE 200
int yydebug;
int yynerrs;
int yyerrflag;
int yychar;
short *yyssp;
YYSTYPE *yyvsp;
YYSTYPE yyval;
YYSTYPE yylval;
short *yyss;
short *yysslim;
YYSTYPE *yyvs;
int yystacksize;
/* allocate initial stack or double stack size, up to YYMAXDEPTH */
static int yygrowstack()
{
    int newsize, i;
    short *newss;
    YYSTYPE *newvs;

    if ((newsize = yystacksize) == 0)
        newsize = YYINITSTACKSIZE;
    else if (newsize >= YYMAXDEPTH)
        return -1;
    else if ((newsize *= 2) > YYMAXDEPTH)
        newsize = YYMAXDEPTH;
    i = yyssp - yyss;
    newss = yyss ? (short *)realloc(yyss, newsize * sizeof *newss) :
      (short *)malloc(newsize * sizeof *newss);
    if (newss == NULL)
        return -1;
    yyss = newss;
    yyssp = newss + i;
    newvs = yyvs ? (YYSTYPE *)realloc(yyvs, newsize * sizeof *newvs) :
      (YYSTYPE *)malloc(newsize * sizeof *newvs);
    if (newvs == NULL)
        return -1;
    yyvs = newvs;
    yyvsp = newvs + i;
    yystacksize = newsize;
    yysslim = yyss + newsize - 1;
    return 0;
}

#define YYABORT goto yyabort
#define YYREJECT goto yyabort
#define YYACCEPT goto yyaccept
#define YYERROR goto yyerrlab

#ifndef YYPARSE_PARAM
#if defined(__cplusplus) || __STDC__
#define YYPARSE_PARAM_ARG void
#define YYPARSE_PARAM_DECL
#else	/* ! ANSI-C/C++ */
#define YYPARSE_PARAM_ARG
#define YYPARSE_PARAM_DECL
#endif	/* ANSI-C/C++ */
#else	/* YYPARSE_PARAM */
#ifndef YYPARSE_PARAM_TYPE
#define YYPARSE_PARAM_TYPE void *
#endif
#if defined(__cplusplus) || __STDC__
#define YYPARSE_PARAM_ARG YYPARSE_PARAM_TYPE YYPARSE_PARAM
#define YYPARSE_PARAM_DECL
#else	/* ! ANSI-C/C++ */
#define YYPARSE_PARAM_ARG YYPARSE_PARAM
#define YYPARSE_PARAM_DECL YYPARSE_PARAM_TYPE YYPARSE_PARAM;
#endif	/* ANSI-C/C++ */
#endif	/* ! YYPARSE_PARAM */

int
yyparse (YYPARSE_PARAM_ARG)
    YYPARSE_PARAM_DECL
{
    register int yym, yyn, yystate;
#if YYDEBUG
    register const char *yys;

    if ((yys = getenv("YYDEBUG")))
    {
        yyn = *yys;
        if (yyn >= '0' && yyn <= '9')
            yydebug = yyn - '0';
    }
#endif

    yynerrs = 0;
    yyerrflag = 0;
    yychar = (-1);

    if (yyss == NULL && yygrowstack()) goto yyoverflow;
    yyssp = yyss;
    yyvsp = yyvs;
    *yyssp = yystate = 0;

yyloop:
    if ((yyn = yydefred[yystate])) goto yyreduce;
    if (yychar < 0)
    {
        if ((yychar = yylex()) < 0) yychar = 0;
#if YYDEBUG
        if (yydebug)
        {
            yys = 0;
            if (yychar <= YYMAXTOKEN) yys = yyname[yychar];
            if (!yys) yys = "illegal-symbol";
            printf("%sdebug: state %d, reading %d (%s)\n",
                    YYPREFIX, yystate, yychar, yys);
        }
#endif
    }
    if ((yyn = yysindex[yystate]) && (yyn += yychar) >= 0 &&
            yyn <= YYTABLESIZE && yycheck[yyn] == yychar)
    {
#if YYDEBUG
        if (yydebug)
            printf("%sdebug: state %d, shifting to state %d\n",
                    YYPREFIX, yystate, yytable[yyn]);
#endif
        if (yyssp >= yysslim && yygrowstack())
        {
            goto yyoverflow;
        }
        *++yyssp = yystate = yytable[yyn];
        *++yyvsp = yylval;
        yychar = (-1);
        if (yyerrflag > 0)  --yyerrflag;
        goto yyloop;
    }
    if ((yyn = yyrindex[yystate]) && (yyn += yychar) >= 0 &&
            yyn <= YYTABLESIZE && yycheck[yyn] == yychar)
    {
        yyn = yytable[yyn];
        goto yyreduce;
    }
    if (yyerrflag) goto yyinrecovery;
#if defined(lint) || defined(__GNUC__)
    goto yynewerror;
#endif
yynewerror:
    yyerror("syntax error");
#if defined(lint) || defined(__GNUC__)
    goto yyerrlab;
#endif
yyerrlab:
    ++yynerrs;
yyinrecovery:
    if (yyerrflag < 3)
    {
        yyerrflag = 3;
        for (;;)
        {
            if ((yyn = yysindex[*yyssp]) && (yyn += YYERRCODE) >= 0 &&
                    yyn <= YYTABLESIZE && yycheck[yyn] == YYERRCODE)
            {
#if YYDEBUG
                if (yydebug)
                    printf("%sdebug: state %d, error recovery shifting\
 to state %d\n", YYPREFIX, *yyssp, yytable[yyn]);
#endif
                if (yyssp >= yysslim && yygrowstack())
                {
                    goto yyoverflow;
                }
                *++yyssp = yystate = yytable[yyn];
                *++yyvsp = yylval;
                goto yyloop;
            }
            else
            {
#if YYDEBUG
                if (yydebug)
                    printf("%sdebug: error recovery discarding state %d\n",
                            YYPREFIX, *yyssp);
#endif
                if (yyssp <= yyss) goto yyabort;
                --yyssp;
                --yyvsp;
            }
        }
    }
    else
    {
        if (yychar == 0) goto yyabort;
#if YYDEBUG
        if (yydebug)
        {
            yys = 0;
            if (yychar <= YYMAXTOKEN) yys = yyname[yychar];
            if (!yys) yys = "illegal-symbol";
            printf("%sdebug: state %d, error recovery discards token %d (%s)\n",
                    YYPREFIX, yystate, yychar, yys);
        }
#endif
        yychar = (-1);
        goto yyloop;
    }
yyreduce:
#if YYDEBUG
    if (yydebug)
        printf("%sdebug: state %d, reducing by rule %d (%s)\n",
                YYPREFIX, yystate, yyn, yyrule[yyn]);
#endif
    yym = yylen[yyn];
    yyval = yyvsp[1-yym];
    switch (yyn)
    {
case 1:
#line 168 "confgrammer.y"
{ INIT(); }
break;
case 3:
#line 173 "confgrammer.y"
{ SET_GLOBAL(); }
break;
case 4:
#line 173 "confgrammer.y"
{ CLEAR_GLOBAL() }
break;
case 6:
#line 175 "confgrammer.y"
{ yyclearin; yyerrok; }
break;
case 7:
#line 176 "confgrammer.y"
{ yyclearin; yyerrok; }
break;
case 8:
#line 180 "confgrammer.y"
{ NEW_SCOPE(yyvsp[-2], yyvsp[0] ); }
break;
case 9:
#line 183 "confgrammer.y"
{ SAVE_SCOPE(); }
break;
case 15:
#line 195 "confgrammer.y"
{ yyclearin; yyerrok; }
break;
case 16:
#line 196 "confgrammer.y"
{ yyclearin; yyerrok; }
break;
case 17:
#line 200 "confgrammer.y"
{ ADD_RANGE2(yyvsp[-2], yyvsp[-1]); }
break;
case 18:
#line 201 "confgrammer.y"
{ ADD_RANGE(yyvsp[-2], yyvsp[-1]); }
break;
case 19:
#line 205 "confgrammer.y"
{ ADD_OPTION(subnetmask, "subnet-mask", yyvsp[-1]); }
break;
case 20:
#line 206 "confgrammer.y"
{ SET_LIST_SA(routers, "routers"); }
break;
case 21:
#line 207 "confgrammer.y"
{ SET_LIST_SA(netbiosNameServers, "netbios-name-servers"); }
break;
case 22:
#line 208 "confgrammer.y"
{ ADD_OPTION(broadcast, "broadcast-address", yyvsp[-1]); }
break;
case 23:
#line 209 "confgrammer.y"
{ SET_LIST_SA(netbiosDDServer, "netbios-dd-server"); }
break;
case 24:
#line 210 "confgrammer.y"
{ ADD_OPTION(netbiosNodeType, "netbios-node-type", yyvsp[-1]); }
break;
case 25:
#line 211 "confgrammer.y"
{ SET_LIST_SA(nameServers, "domain-name-servers"); }
break;
case 26:
#line 212 "confgrammer.y"
{ ADD_OPTIONQ(nisDomain, "nis-domain", yyvsp[-2]); }
break;
case 27:
#line 213 "confgrammer.y"
{ ADD_OPTIONQ(domainName, "domain-name", yyvsp[-2]); }
break;
case 28:
#line 214 "confgrammer.y"
{ ADD_OPTION(timeOffset, "time-offset", yyvsp[-1]); }
break;
case 29:
#line 215 "confgrammer.y"
{ ADD_OPTION_TIME(leaseDurations, "default-lease-time", yyvsp[-1]); }
break;
case 30:
#line 216 "confgrammer.y"
{ ADD_OPTION_TIME(maxLeaseDurations, "max-lease-time", yyvsp[-1]); }
break;
case 31:
#line 220 "confgrammer.y"
{ NEW_HOST(yyvsp[0]) }
break;
case 32:
#line 223 "confgrammer.y"
{ SAVE_HOST(); }
break;
case 36:
#line 230 "confgrammer.y"
{ yyclearin; yyerrok; }
break;
case 37:
#line 231 "confgrammer.y"
{ yyclearin; yyerrok; }
break;
case 38:
#line 235 "confgrammer.y"
{ ADD_OPTION2(fixedaddress, "fixed-address", yyvsp[-1]); }
break;
case 39:
#line 236 "confgrammer.y"
{ ADD_OPTION2(nextserver, "next-server", yyvsp[-1]); }
break;
case 40:
#line 237 "confgrammer.y"
{ ADD_OPTION2(hardware_ethernet, "hardware ethernet", yyvsp[-1]); }
break;
case 41:
#line 241 "confgrammer.y"
{ ip_list = yyvsp[0]; }
break;
case 42:
#line 242 "confgrammer.y"
{ ip_list = "\""; ip_list += yyvsp[-1]; ip_list += "\""; }
break;
case 43:
#line 243 "confgrammer.y"
{ ip_list += ", "; ip_list += yyvsp[0]; }
break;
case 44:
#line 244 "confgrammer.y"
{ ip_list += ", "; ip_list += "\""; ip_list += yyvsp[-1]; ip_list += "\""; }
break;
case 47:
#line 253 "confgrammer.y"
{ SET_COMMENT(yyvsp[0]); }
break;
#line 765 "confgrammer.tab.c"
    }
    yyssp -= yym;
    yystate = *yyssp;
    yyvsp -= yym;
    yym = yylhs[yyn];
    if (yystate == 0 && yym == 0)
    {
#if YYDEBUG
        if (yydebug)
            printf("%sdebug: after reduction, shifting from state 0 to\
 state %d\n", YYPREFIX, YYFINAL);
#endif
        yystate = YYFINAL;
        *++yyssp = YYFINAL;
        *++yyvsp = yyval;
        if (yychar < 0)
        {
            if ((yychar = yylex()) < 0) yychar = 0;
#if YYDEBUG
            if (yydebug)
            {
                yys = 0;
                if (yychar <= YYMAXTOKEN) yys = yyname[yychar];
                if (!yys) yys = "illegal-symbol";
                printf("%sdebug: state %d, reading %d (%s)\n",
                        YYPREFIX, YYFINAL, yychar, yys);
            }
#endif
        }
        if (yychar == 0) goto yyaccept;
        goto yyloop;
    }
    if ((yyn = yygindex[yym]) && (yyn += yystate) >= 0 &&
            yyn <= YYTABLESIZE && yycheck[yyn] == yystate)
        yystate = yytable[yyn];
    else
        yystate = yydgoto[yym];
#if YYDEBUG
    if (yydebug)
        printf("%sdebug: after reduction, shifting from state %d \
to state %d\n", YYPREFIX, *yyssp, yystate);
#endif
    if (yyssp >= yysslim && yygrowstack())
    {
        goto yyoverflow;
    }
    *++yyssp = yystate;
    *++yyvsp = yyval;
    goto yyloop;
yyoverflow:
    yyerror("yacc stack overflow");
yyabort:
    return (1);
yyaccept:
    return (0);
}
