%option case-insensitive
%option noyywrap
%option 8bit
%{
/***************************************************************************
                          conftokens.flex  -  description
                             -------------------
    copyright            : (C) 2002 by Willy De la Court
    email                : willy.delacourt@pandora.be
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License version 2 as     *
 *   published by the Free Software Foundation                             *
 *                                                                         *
 ***************************************************************************/

#define YYSTYPE char *

#include "confgrammer.h"
#include <string.h>

static int my_conf_input( char *buffer, int max_size );
#define YY_INPUT( buffer, result, max_size ) { result = my_conf_input( buffer, max_size ); }

int conf_lineno;
extern YYSTYPE conf_yylval;
int conf_yypos = 0;
const char *conf_lexinput;

//#define DEBUG 1
#ifdef DEBUG
#define PDEBUG(x, y) printf(x, y)
#else
#define PDEBUG(x, y) 
#endif

#define RETURN(val) {PDEBUG("[%s] ", yytext); return val;}
#define RETURNVAL(val, txt) {conf_yylval = strdup(yytext); PDEBUG(txt, yytext); return val; }
%}
%%

"subnet-mask"		RETURN(SUBNETMASK);
"nis-domain"		RETURN(NISDOMAIN);
"ip-forwarding"		RETURN(IPFORWARDING);
"domain-name-servers"	RETURN(DOMAINNAMESERVERS);
"domain-name"		RETURN(DOMAINNAME)
"routers"		RETURN(ROUTERS);
"netbios-name-servers"	RETURN(NETBIOSNAMESERVERS);
"netbios-dd-server"	RETURN(NETBIOSDDSERVER);
"netbios-node-type"	RETURN(NETBIOSNODETYPE);
"broadcast-address"	RETURN(BROADCASTADDRESS);
"subnet"		RETURN(SUBNET);
"range"			RETURN(RANGE);
"host"			RETURN(HOST);
"next-server"		RETURN(NEXTSERVER);
"fixed-address"		RETURN(FIXEDADDRESS);
"hardware"		RETURN(HARDWARE);
"ethernet"		RETURN(ETHERNET);
"netmask"		RETURN(NETMASK);
"dynamic-bootp"		RETURN(DYNAMICBOOTP);
"default-lease-time"	RETURN(DEFAULTLEASETIME);
"max-lease-time"	RETURN(MAXLEASETIME);
"time-offset"		RETURN(TIMEOFFSET);
"option"		RETURN(OPTION);
[0-9]+\.[0-9]+\.[0-9]+\.[0-9]+		RETURNVAL(IP, "IP[%s]");
[0-9]+|\-[0-9]+				RETURNVAL(NUMBER, "NUMBER[%s]");
[a-zA-Z0-9][a-zA-Z0-9-]*		RETURNVAL(WORD, "WORD[%s]");
[a-zA-Z0-9][a-zA-Z0-9-]*\.[a-zA-Z0-9][a-zA-Z0-9.-]*	RETURNVAL(DOMAIN, "DOMAIN[%s]");
[a-fA-F0-9][a-fA-F0-9]\:[a-fA-F0-9][a-fA-F0-9]\:[a-fA-F0-9][a-fA-F0-9]\:[a-fA-F0-9][a-fA-F0-9]\:[a-fA-F0-9][a-fA-F0-9]\:[a-fA-F0-9][a-fA-F0-9]	RETURNVAL(MAC, "MAC[%s]");
"\."			RETURN('.');
"-"			RETURN('-');
"\""			RETURN(QUOTE);
";"			RETURN(';');
"{"			RETURN('{');
"}"			RETURN('}');
#[^\n]+\n		 conf_lineno++; RETURNVAL(COMMENT, "COMMENT[%s]");
\n              	/* ignore EOL */ PDEBUG("\n", ""); conf_lineno++;
[ \t]+          	/* ignore whitespace */;
.			return( (int) yytext[0]);
%%


static int my_conf_input( char *buffer, int max_size )
{
	int n = 0;
	char *inp_str = (char *) conf_lexinput + conf_yypos;
	n = ( int ) strlen( inp_str );
 
	if ( n > max_size )
	{
		conf_yypos = conf_yypos + max_size;
		n = max_size;
	}
	else
		conf_yypos = conf_yypos + n;
	memcpy( buffer, inp_str, n );
	return n;
}
